@@ -1,4 +1,3 @@
-#' @importFrom dplyr %>%
 #' @importFrom dplyr pull
 #' @importFrom readr read_csv
 #' @importFrom tidyr separate pivot_wider
@@ -6,9 +5,6 @@
 #' @importFrom tibble tibble as_tibble
 #'
 
-#' @export
-dplyr::`%>%`
-
 #' @keywords internal
 "_PACKAGE"
 
