@@ -77,9 +77,9 @@ fetch_cricket_data <- function(matchtype = c("test", "odi", "t20"),
         stop("No data available")
       }
       maxpage <- as.numeric(strsplit(dplyr::pull(tables[[2]][1, 1]), "Page 1 of ")[[1]][2])
-      pb <- cli::cli_progress_bar("Downloading", total = maxpage)
-      cli::cli_progress_update()
-      Sys.sleep(1 / 1000)
+      cli::cli_progress_bar("Downloading", total = maxpage)
+      #cli::cli_progress_update()
+      #Sys.sleep(1 / 1000)
     }
     if (!theend) {
       # Make allcolumns characters for now.
