@@ -6,12 +6,13 @@
 #' Data must be specified by three factors:
 #' (a) type of data: `bbb` (ball-by-ball), `match` or `player`.
 #' (b) gender;
-#' (c) competition.
-#' See \url{https://cricsheet.org/downloads/} for what the competition character codes mean.
+#' (c) competition specified as a Cricsheet code. See \code{\link{cricsheet_codes}} for the
+#' competitions and codes available.
 #'
 #' @param type Character string giving type of data: ball-by-ball, match info or player info.
 #' @param gender Character string giving player gender: female or male.
-#' @param competition Character string giving name of competition.
+#' @param competition Character string giving code corresponding to competition. See \code{\link{cricsheet_codes}} for the
+#' competitions and codes available.
 #' @author Jacquie Tran, Hassan Rafique and Rob J Hyndman
 #' @return A \code{tibble} object, similar to a \code{data.frame}.
 #' @examples
@@ -25,23 +26,13 @@
 fetch_cricsheet <- function(
     type = c("bbb", "match", "player"),
     gender = c("female", "male"),
-    competition = c("tests", "multi_day", "odis", "odms",
-                    "t20is", "t20is_unofficial",
-                    "apl", "bbl", "bpl", "county", "edwards_cup", "cpl",
-                    "the_hundred", "ipl", "lpl", "msl", "t20_blast",
-                    "psl", "heyhoe_flint_trophy", "sheffield_shield", "super_smash",
-                    "wbbl", "wt20c")
-  ) {
+    competition = "tests") {
   # Match arguments
   type <- match.arg(type)
   gender <- match.arg(gender)
-  competition <- match.arg(competition)
 
-  # Construct codes for cricsheet files
-  formal.args <- formals(sys.function(sysP <- sys.parent()))
-  choices <- eval(formal.args[["competition"]], envir = sys.frame(sysP))
-  code_table <- data.frame(competition = choices)
-  code_table$code <- dplyr::recode(code_table$competition,
+  # Convert code for backwards compatibility
+  competition <- dplyr::recode(competition,
     county = "cch",
     edwards_cup = "cec",
     heyhoe_flint_trophy = "rhf",
@@ -55,9 +46,8 @@ fetch_cricsheet <- function(
     wbbl = "wbb",
     wt20c = "wtc"
   )
-  code <- code_table[code_table$competition == competition, "code"]
   # Construct file names and url
-  destfile <- paste0(code, "_", gender, "_csv2.zip")
+  destfile <- paste0(competition, "_", gender, "_csv2.zip")
   url <- paste0("https://cricsheet.org/downloads/", destfile)
   subdir <- paste0(sub("_csv2.zip", "", destfile), "_bbb")
   destfile <- file.path(tempdir(), destfile)
@@ -95,17 +85,22 @@ fetch_cricsheet <- function(
   match_filepaths <- file.path(tempdir(), subdir, match_files)
 
   if (type == "bbb") {
-      # Read data from CSVs stored in the temp directory
-      all_matches <- do.call("rbind",
-        lapply(match_filepaths, FUN = function(files) { read.csv(files) })
-      )
+    # Read data from CSVs stored in the temp directory
+    all_matches <- do.call(
+      "rbind",
+      lapply(match_filepaths, FUN = function(files) {
+        read.csv(files)
+      })
+    )
   } else {
     all_matches <- suppressWarnings(
       readr::read_csv(
-        match_filepaths, id = "path", guess_max = 100,
+        match_filepaths,
+        id = "path", guess_max = 100,
         col_names = c("col_to_delete", "key", "value"),
         skip = 1, show_col_types = FALSE,
-        col_types = readr::cols(.default = readr::col_character()))
+        col_types = readr::cols(.default = readr::col_character())
+      )
     )
     # Note: Warning suppressed because the source data
     # changes format slightly when displaying player metadata compared to match data
@@ -152,12 +147,12 @@ fetch_cricsheet <- function(
   output <- tibble::as_tibble(all_matches)
 
   # Clean data
-  t20 <- competition %in% c(
-    "t20is", "t20is_unofficial",
-    "apl", "bbl", "bpl", "edwards_cup", "cpl",
-    "ipl", "lpl", "msl", "t20_blast",
-    "psl", "super_smash", "wbbl", "wt20c"
-  )
+  # Was it a T20 match?
+  if (!("ball" %in% colnames(output))) {
+    t20 <- FALSE
+  } else {
+    t20 <- max(output$ball, na.rm = TRUE) <= 21
+  }
   if (type == "bbb" & t20) {
     output <- cleaning_bbb_t20_cricsheet(output)
   }
@@ -188,7 +183,7 @@ cleaning_bbb_t20_cricsheet <- function(df) {
     dplyr::inner_join(
       df |>
         dplyr::group_by(match_id, innings) |>
-        dplyr::summarise(
+        dplyr::reframe(
           runs_scored_yet = cumsum(runs_off_bat + extras),
           wickets_lost_yet = cumsum(wicket),
           ball = ball, over = over,
@@ -200,7 +195,7 @@ cleaning_bbb_t20_cricsheet <- function(df) {
   # Evaluating the balls in over after adjusting for extra balls and balls remaining in an innings
   remaining_balls <- df |>
     dplyr::group_by(match_id, innings, over) |>
-    dplyr::summarise(ball = ball, extra_ball = cumsum(extra_ball), .groups = "drop") |>
+    dplyr::reframe(ball = ball, extra_ball = cumsum(extra_ball)) |>
     dplyr::mutate(
       ball_in_over = ball - extra_ball,
       balls_remaining = ifelse(innings %in% c(1, 2), 120 - ((over - 1) * 6 + ball_in_over), 6 - ball_in_over)
@@ -210,7 +205,7 @@ cleaning_bbb_t20_cricsheet <- function(df) {
   # Evaluating innings totals using ball-by-ball data
   innings_total <- df |>
     dplyr::group_by(match_id, innings) |>
-    dplyr::summarise(total_score = sum(runs_off_bat + extras), .groups = "drop") |>
+    dplyr::reframe(total_score = sum(runs_off_bat + extras)) |>
     tidyr::pivot_wider(
       names_from  = "innings",
       values_from = c("total_score")
@@ -222,7 +217,8 @@ cleaning_bbb_t20_cricsheet <- function(df) {
   df <- df |>
     dplyr::inner_join(remaining_balls, by = c("match_id", "innings", "over", "ball")) |>
     dplyr::inner_join(innings_total, by = "match_id") |>
-    dplyr::mutate(target = innings1_total + 1)
+    dplyr::mutate(target = innings1_total + 1) |> 
+    dplyr::mutate(start_date = as.Date(start_date))
 
   # Re-ordering the columns in the df
   df <- df |>
